@@ -7,21 +7,11 @@
 #include "AppStreamUtils.h"
 
 #include "utils.h"
-
-#ifdef DISCOVER_USE_STABLE_APPSTREAM
-#include <AppStreamQt5/pool.h>
-#include <AppStreamQt5/release.h>
-#include <AppStreamQt5/screenshot.h>
-#include <AppStreamQt5/spdx.h>
-#include <AppStreamQt5/version.h>
-#else
 #include <AppStreamQt/pool.h>
 #include <AppStreamQt/release.h>
 #include <AppStreamQt/screenshot.h>
 #include <AppStreamQt/spdx.h>
 #include <AppStreamQt/version.h>
-#endif
-
 #include <Category/Category.h>
 #include <KLocalizedString>
 #include <QDebug>
@@ -69,21 +59,19 @@ QString AppStreamUtils::changelogToHtml(const AppStream::Component &appdata)
 
 Screenshots AppStreamUtils::fetchScreenshots(const AppStream::Component &appdata)
 {
-#if ASQ_CHECK_VERSION(1, 0, 0)
     const auto appdataScreenshots = appdata.screenshotsAll();
-#else
-    const auto appdataScreenshots = appdata.screenshots();
-#endif
     Screenshots ret;
     ret.reserve(appdataScreenshots.size());
     for (const AppStream::Screenshot &s : appdataScreenshots) {
         const auto images = s.images();
         const QUrl thumbnail = AppStreamUtils::imageOfKind(images, AppStream::Image::KindThumbnail);
-        const QUrl plain = AppStreamUtils::imageOfKind(images, AppStream::Image::KindSource);
-        if (plain.isEmpty())
-            qWarning() << "invalid screenshot for" << appdata.name();
+        const QUrl full = AppStreamUtils::imageOfKind(images, AppStream::Image::KindSource);
+        if (full.isEmpty()) {
+            qWarning() << "AppStreamUtils: Invalid screenshot for" << appdata.name();
+        }
+        const bool isAnimated = s.mediaKind() == AppStream::Screenshot::MediaKindVideo;
 
-        ret.append(Screenshot{plain, thumbnail.isEmpty() ? plain : thumbnail, s.mediaKind() == AppStream::Screenshot::MediaKindVideo});
+        ret.append(Screenshot{thumbnail.isEmpty() ? full : thumbnail, full, isAnimated});
     }
     return ret;
 }
@@ -95,14 +83,20 @@ QJsonArray AppStreamUtils::licenses(const AppStream::Component &appdata)
 
 QJsonArray AppStreamUtils::licenses(const QString &spdx)
 {
-    static const QSet<QChar> tokens = {'&', '+', '|', '^', '(', ')'};
+    static const QSet<QChar> tokens = {QLatin1Char('&'), QLatin1Char('+'), QLatin1Char('|'), QLatin1Char('^'), QLatin1Char('('), QLatin1Char(')')};
 
     QJsonArray ret;
     const auto licenses = AppStream::SPDX::tokenizeLicense(spdx);
     for (const auto &token : licenses) {
         if (token.size() == 1 && tokens.contains(token.at(0)))
             continue;
-        ret += license(token.mid(1)); // tokenize prefixes with an @ for some reason
+
+        // Sometimes tokenize prefixes with an @ for some reason
+        if (token.startsWith(QStringLiteral("@"))) {
+            ret += license(token.mid(1));
+        } else {
+            ret += license(token);
+        }
     }
     return ret;
 }
@@ -145,35 +139,20 @@ QStringList AppStreamUtils::appstreamIds(const QUrl &appstreamUrl)
         ret << query.queryItemValue(QStringLiteral("alt")).split(QLatin1Char(','), Qt::SkipEmptyParts);
     }
     if (ret.removeDuplicates() != 0) {
-        qDebug() << "received malformed url" << appstreamUrl;
+        qDebug() << "AppStreamUtils: Received malformed url" << appstreamUrl;
     }
     return ret;
 }
 
 QString AppStreamUtils::versionString(const QString &version, const AppStream::Component &appdata)
 {
+    Q_UNUSED(appdata);
+
     if (version.isEmpty()) {
         return {};
-    } else {
-#if ASQ_CHECK_VERSION(1, 0, 0)
-        if (appdata.releasesPlain().isEmpty()) {
-            return version;
-        }
-        auto release = appdata.releasesPlain().indexSafe(0).value();
-#else
-        if (appdata.releases().isEmpty()) {
-            return version;
-        }
-        auto release = appdata.releases().constFirst();
-#endif
-
-        if (release.timestamp().isValid() && version.startsWith(release.version())) {
-            QLocale l;
-            return i18n("%1, released on %2", version, l.toString(release.timestamp().date(), QLocale::ShortFormat));
-        } else {
-            return version;
-        }
     }
+
+    return version;
 }
 
 QString AppStreamUtils::contentRatingDescription(const AppStream::Component &appdata)
@@ -270,7 +249,7 @@ uint AppStreamUtils::contentRatingMinimumAge(const AppStream::Component &appdata
 #endif
 }
 
-static void kRemoveDuplicates(QList<AppStream::Component> &input, AppStream::Bundle::Kind kind)
+static void kRemoveDuplicates(AppStream::ComponentBox &input, AppStream::Bundle::Kind kind)
 {
     QSet<QString> ret;
     for (auto it = input.begin(); it != input.end();) {
@@ -284,15 +263,11 @@ static void kRemoveDuplicates(QList<AppStream::Component> &input, AppStream::Bun
     }
 }
 
-QList<AppStream::Component> AppStreamUtils::componentsByCategories(AppStream::Pool *pool, Category *cat, AppStream::Bundle::Kind kind)
+AppStream::ComponentBox AppStreamUtils::componentsByCategories(AppStream::Pool *pool, Category *cat, AppStream::Bundle::Kind kind)
 {
-    QList<AppStream::Component> ret;
+    AppStream::ComponentBox ret(AppStream::ComponentBox::FlagNoChecks);
     for (const auto &categoryName : cat->involvedCategories()) {
-#if ASQ_CHECK_VERSION(1, 0, 0)
-        ret += pool->componentsByCategories({categoryName}).toList();
-#else
         ret += pool->componentsByCategories({categoryName});
-#endif
     }
     kRemoveDuplicates(ret, kind);
     return ret;
