@@ -22,6 +22,7 @@ class DISCOVERCOMMON_EXPORT OdrsReviewsBackend : public AbstractReviewsBackend
 {
     Q_OBJECT
 public:
+    static QSharedPointer<OdrsReviewsBackend> global();
     explicit OdrsReviewsBackend();
     ~OdrsReviewsBackend() override;
 
@@ -35,7 +36,7 @@ public:
     {
     }
 
-    Rating *ratingForApplication(AbstractResource *app) const override;
+    Rating ratingForApplication(AbstractResource *resource) const override;
     bool hasCredentials() const override
     {
         return false;
@@ -47,7 +48,7 @@ public:
     void deleteReview(Review *) override
     {
     }
-    void fetchReviews(AbstractResource *app, int page = 1) override;
+    void fetchReviews(AbstractResource *resource, int page = 1) override;
     bool isFetching() const override
     {
         return m_isFetching;
@@ -56,14 +57,14 @@ public:
     {
     }
     void submitUsefulness(Review *review, bool useful) override;
-    bool isResourceSupported(AbstractResource *res) const override;
-    void emitRatingFetched(AbstractResourcesBackend *backend, const QList<AbstractResource *> &res) const;
+    bool isResourceSupported(AbstractResource *resource) const override;
+    void emitRatingFetched(AbstractResourcesBackend *backend, const QList<AbstractResource *> &resources) const;
     QString errorMessage() const override
     {
         return m_errorMessage;
     }
 
-    QVector<Rating *> top() const
+    const QList<Rating> &top() const
     {
         return m_top;
     }
@@ -78,20 +79,20 @@ Q_SIGNALS:
     void ratingsReady();
 
 protected:
-    void sendReview(AbstractResource *app, const QString &summary, const QString &review_text, const QString &rating, const QString &userName) override;
+    void sendReview(AbstractResource *resource, const QString &summary, const QString &reviewText, const QString &rating, const QString &userName) override;
     QString userName() const override;
 
 private:
     void fetchRatings();
-    void setFetching(bool);
+    void setFetching(bool fetching);
     QNetworkAccessManager *nam();
     void parseRatings();
     void parseReviews(const QJsonDocument &document, AbstractResource *resource);
 
     QString m_errorMessage;
-    QHash<QString, Rating *> m_ratings;
+    QHash<QString, Rating> m_ratings;
     bool m_isFetching = false;
     CachedNetworkAccessManager *m_delayedNam = nullptr;
 
-    QVector<Rating *> m_top;
+    QList<Rating> m_top;
 };
