@@ -12,14 +12,13 @@
 #include "FlatpakPermission.h"
 #include "flatpak-helper.h"
 
-#ifdef DISCOVER_USE_STABLE_APPSTREAM
-#include <AppStreamQt5/component.h>
-#else
 #include <AppStreamQt/component.h>
-#endif
 
 #include <QAbstractItemModel>
 #include <QPixmap>
+
+#include <QCoroTask>
+
 #include <optional>
 
 class AddonList;
@@ -29,14 +28,14 @@ class FlatpakSource;
 class FlatpakResource : public AbstractResource
 {
     Q_OBJECT
-    Q_PROPERTY(QStringList topObjects MEMBER s_objects CONSTANT)
-    Q_PROPERTY(QStringList objects MEMBER s_bottomObjects CONSTANT)
     Q_PROPERTY(QString attentionText READ attentionText CONSTANT)
     Q_PROPERTY(QString dataLocation READ dataLocation CONSTANT)
     Q_PROPERTY(QString branch READ branch CONSTANT)
     Q_PROPERTY(bool isDesktopApp READ isDesktopApp CONSTANT)
     Q_PROPERTY(QString eolReason READ eolReason NOTIFY eolReasonChanged)
     Q_PROPERTY(bool hasData READ hasData NOTIFY hasDataChanged)
+    Q_PROPERTY(QString ref READ ref CONSTANT)
+
 public:
     explicit FlatpakResource(const AppStream::Component &component, FlatpakInstallation *installation, FlatpakBackend *parent);
 
@@ -88,7 +87,9 @@ public:
         }
     };
 
-    static QString typeAsString(ResourceType type)
+    FlatpakBackend *backend() const;
+
+    static QLatin1String typeAsString(ResourceType type)
     {
         if (type == DesktopApp) {
             return QLatin1String("app");
@@ -108,7 +109,6 @@ public:
     bool canExecute() const override;
     QStringList categories() override;
     QString comment() override;
-    QString commit() const;
     quint64 downloadSize() const;
     QVariant icon() const override;
     QString installedVersion() const override;
@@ -135,7 +135,7 @@ public:
     QString sizeDescription() override;
     AbstractResource::State state() override;
     ResourceType resourceType() const;
-    QString typeAsString() const;
+    QLatin1String typeAsString() const;
     FlatpakResource::Id uniqueId() const;
     QUrl url() const override;
     QDate releaseDate() const override;
@@ -205,11 +205,21 @@ public:
     QString contentRatingDescription() const override;
     ContentIntensity contentRatingIntensity() const override;
     uint contentRatingMinimumAge() const override;
+
+    QStringList topObjects() const override;
+    QStringList bottomObjects() const override;
+
     bool isDesktopApp() const
     {
         return m_type == DesktopApp;
     }
     QString eolReason();
+    void addRefToUpdate(const QByteArray &toUpdate);
+    void clearToUpdate();
+    QVector<QByteArray> toUpdate() const
+    {
+        return m_toUpdate;
+    }
 
 Q_SIGNALS:
     void hasDataChanged();
@@ -217,14 +227,13 @@ Q_SIGNALS:
     void eolReasonChanged();
 
 private:
-    void setCommit(const QString &commit);
+    void setEolReason(const QString &reason);
     void loadPermissions();
 
     const AppStream::Component m_appdata;
     FlatpakResource::Id m_id;
     FlatpakRefKind m_flatpakRefKind;
     QPixmap m_bundledIcon;
-    QString m_commit;
     qint64 m_downloadSize;
     FlatpakFileType m_flatpakFileType = FlatpakResource::NotAFile;
     QString m_flatpakName;
@@ -243,8 +252,11 @@ private:
     QSharedPointer<FlatpakSource> m_temp;
     QVector<FlatpakPermission> m_permissions;
     std::optional<QString> m_eolReason;
-    static const QStringList s_objects;
+    std::optional<QCoro::Task<>> m_eolReasonTask;
+    static const QStringList s_topObjects;
     static const QStringList s_bottomObjects;
+    QVector<QByteArray> m_toUpdate;
+    bool m_stockIcon;
 };
 
 inline uint qHash(const FlatpakResource::Id &key)
