@@ -6,22 +6,13 @@
 
 #include "AppPackageKitResource.h"
 #include "utils.h"
-
-#ifdef DISCOVER_USE_STABLE_APPSTREAM
-#include <AppStreamQt5/developer.h>
-#include <AppStreamQt5/icon.h>
-#include <AppStreamQt5/image.h>
-#include <AppStreamQt5/release.h>
-#include <AppStreamQt5/screenshot.h>
-#include <AppStreamQt5/version.h>
-#else
+#include <AppStreamQt/developer.h>
 #include <AppStreamQt/icon.h>
 #include <AppStreamQt/image.h>
 #include <AppStreamQt/release.h>
 #include <AppStreamQt/screenshot.h>
 #include <AppStreamQt/version.h>
-#endif
-
+#include <KIconLoader>
 #include <KLocalizedString>
 #include <KService>
 #include <PackageKit/Daemon>
@@ -33,6 +24,8 @@
 #include <QUrlQuery>
 #include <appstream/AppStreamUtils.h>
 
+using namespace Qt::StringLiterals;
+
 AppPackageKitResource::AppPackageKitResource(const AppStream::Component &data, const QString &packageName, PackageKitBackend *parent)
     : PackageKitResource(packageName, QString(), parent)
     , m_appdata(data)
@@ -46,14 +39,16 @@ QString AppPackageKitResource::name() const
         if (!m_appdata.extends().isEmpty()) {
             const auto components = backend()->componentsById(m_appdata.extends().constFirst());
 
-            if (components.isEmpty())
+            if (components.isEmpty()) {
                 qWarning() << "couldn't find" << m_appdata.extends() << "which is supposedly extended by" << m_appdata.id();
-            else
-                m_name = components.constFirst().name() + QLatin1String(" - ") + m_appdata.name();
+            } else {
+                m_name = components.indexSafe(0)->name() + QLatin1String(" - ") + m_appdata.name();
+            }
         }
 
-        if (m_name.isEmpty())
+        if (m_name.isEmpty()) {
             m_name = m_appdata.name();
+        }
     }
     return m_name;
 }
@@ -61,8 +56,9 @@ QString AppPackageKitResource::name() const
 QString AppPackageKitResource::longDescription()
 {
     const auto desc = m_appdata.description();
-    if (!desc.isEmpty())
+    if (!desc.isEmpty()) {
         return desc;
+    }
 
     return PackageKitResource::longDescription();
 }
@@ -81,9 +77,9 @@ static QIcon componentIcon(const AppStream::Component &comp)
             ret.addFile(icon.url().toLocalFile(), icon.size());
             break;
         case AppStream::Icon::KindStock: {
-            const auto ret = QIcon::fromTheme(icon.name());
-            if (!ret.isNull())
-                return ret;
+            if (KIconLoader::global()->hasIcon(icon.name())) {
+                return QIcon::fromTheme(icon.name());
+            }
             break;
         }
         default:
@@ -116,16 +112,18 @@ static constexpr auto s_addonKinds = {AppStream::Component::KindAddon, AppStream
 QStringList AppPackageKitResource::categories()
 {
     auto cats = m_appdata.categories();
-    if (!kContainsValue(s_addonKinds, m_appdata.kind()))
+    if (!kContainsValue(s_addonKinds, m_appdata.kind())) {
         cats.append(QStringLiteral("Application"));
+    }
     return cats;
 }
 
 QString AppPackageKitResource::comment()
 {
     const auto summary = m_appdata.summary();
-    if (!summary.isEmpty())
+    if (!summary.isEmpty()) {
         return summary;
+    }
 
     return PackageKitResource::comment();
 }
@@ -150,7 +148,7 @@ QUrl AppPackageKitResource::url() const
     provided.removeAll(appstreamId()); // Just in case, it has happened before
     if (!provided.isEmpty()) {
         QUrlQuery qq;
-        qq.addQueryItem("alt", provided.join(QLatin1Char(',')));
+        qq.addQueryItem(u"alt"_s, provided.join(QLatin1Char(',')));
         ret.setQuery(qq);
     }
     return ret;
@@ -204,10 +202,13 @@ QStringList AppPackageKitResource::allPackageNames() const
 
 QList<PackageState> AppPackageKitResource::addonsInformation()
 {
-    const auto res = kFilter<QVector<AppPackageKitResource *>>(backend()->extendedBy(m_appdata.id()), [this](AppPackageKitResource *r) {
-        return r->allPackageNames() != allPackageNames();
+    const auto extendedBy = backend()->extendedBy(m_appdata.id());
+    const auto allPackageNamesCached = allPackageNames();
+    const auto resources = kFilter<QVector<AbstractResource *>>(extendedBy, [&](AbstractResource *r) {
+        auto apkr = qobject_cast<AppPackageKitResource *>(r);
+        return apkr && apkr->allPackageNames() != allPackageNamesCached;
     });
-    return kTransform<QList<PackageState>>(res, [](AppPackageKitResource *r) {
+    return kTransform<QList<PackageState>>(resources, [](AbstractResource *r) {
         return PackageState(r->packageName(), r->name(), r->comment(), r->isInstalled());
     });
 }
@@ -249,8 +250,8 @@ QString AppPackageKitResource::versionString()
 QDate AppPackageKitResource::releaseDate() const
 {
 #if ASQ_CHECK_VERSION(1, 0, 0)
-    if (const auto optional = m_appdata.releasesPlain().indexSafe(0); optional.has_value()) {
-        auto release = optional.value();
+    if (!m_appdata.releasesPlain().isEmpty()) {
+        const auto release = m_appdata.releasesPlain().indexSafe(0).value();
 #else
     if (!m_appdata.releases().isEmpty()) {
         const auto release = m_appdata.releases().constFirst();
@@ -263,11 +264,7 @@ QDate AppPackageKitResource::releaseDate() const
 
 QString AppPackageKitResource::author() const
 {
-#if ASQ_CHECK_VERSION(1, 0, 0)
     QString name = m_appdata.developer().name();
-#else
-    QString name = m_appdata.developerName();
-#endif
 
     if (name.isEmpty()) {
         name = m_appdata.projectGroup();
@@ -305,3 +302,5 @@ uint AppPackageKitResource::contentRatingMinimumAge() const
 {
     return AppStreamUtils::contentRatingMinimumAge(m_appdata);
 }
+
+#include "moc_AppPackageKitResource.cpp"
